#-*- coding:utf-8 -*-

#    Gedit but_active plugin version 1.1.0
#    Copyright © 2009 sasakima-nao <sasakimanao@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    2013.11.03 Version 1.1.0
#    Support Gedit 3.8 (Python3)
#    Keyboard ShortCut <Control><Shift><Alt>W
#
#    2009.05.16 Version 1.0.0

import gedit
import gtk

ui_str = """<ui>
    <popup name="NotebookPopup">
        <separator/>
        <menuitem name="but_active" action="but_active"/>
    </popup>
</ui>
"""

class But_Active(gedit.Plugin):
    def __init__(self):
        gedit.Plugin.__init__(self)

    def activate(self, window):
        self._window = window
        self.tab_list = []
        # GtkUIManager を得る
        manager = self._window.get_ui_manager()
        # GtkActionGroup を新規で作成
        self._action_group = gtk.ActionGroup("but_activeActions")
        # GtkActionEntry を作成
        # name, stock_id, label, accelerator, tooltip, callback
        actions = [("but_active", None, "アクティブ以外全部閉じる", "<Control><Shift><Alt>W",
                    "アクティブなタブ以外全部閉じる", self.on_but_active_activate)]
        # GtkActionGroup に挿入
        self._action_group.add_actions(actions)
        # GtkUIManager に追加
        manager.insert_action_group(self._action_group, -1)
        self._ui_id = manager.add_ui_from_string(ui_str)
        # window のシグナル接続
        self.id1 = self._window.connect("tab-added", self.on_tab_added)
        self.id2 = self._window.connect("tab-removed", self.on_tab_removed)

    def deactivate(self, window):
        manager = self._window.get_ui_manager()
        manager.remove_ui(self._ui_id)
        manager.remove_action_group(self._action_group)
        manager.ensure_update()
        # シグナルの切断を忘れずに
        self._window.disconnect(self.id1)
        self._window.disconnect(self.id2)

    def update_ui(self, window):
        pass

    def on_tab_added(self, window, tab):
        self.tab_list.append(tab)

    def on_tab_removed(self, window, tab):
        self.tab_list.remove(tab)

    def on_but_active_activate(self, action):
        ac = self._window.get_active_tab()
        # removed に左右されるのでコピーしてからループ
        copy_list = self.tab_list[:]
        for tab in copy_list:
            if tab != ac:
                self._window.close_tab(tab)
