#-*- coding:utf-8 -*-

#    Gedit lf_to_br plugin version 1.1.0
#    Copyright © 2009 sasakima-nao <sasakimanao@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    2013.11.03 Version 1.1.0
#    Support CRLF
#    Fix: GtkActionGroup Name
#
#    2009.03.12 Version 1.0.0

import gedit
import gtk

ui_str = """<ui>
    <menubar name="MenuBar">
        <menu name="EditMenu" action="Edit">
            <placeholder name="EditOps_3">
                <menuitem name="LF_ON_BR" action="LF_ON_BR"/>
            </placeholder>
        </menu>
    </menubar>
</ui>
"""

class LF_on_BR(gedit.Plugin):
    def __init__(self):
        gedit.Plugin.__init__(self)

    def activate(self, window):
        self._window = window
        # GtkUIManager を得る
        manager = self._window.get_ui_manager()
        # GtkActionGroup を新規で作成
        self._action_group = gtk.ActionGroup("LFonBRActions")
        # GtkActionEntry を作成
        # name, stock_id, label, accelerator, tooltip, callback
        actions = [("LF_ON_BR", None, "LF 位置に <br />", None, "選択範囲の改行位置に <br /> を追記", self.on_lf_to_br_activate)]
        # GtkActionGroup に挿入
        self._action_group.add_actions(actions)
        # GtkUIManager に追加
        manager.insert_action_group(self._action_group, -1)
        self._ui_id = manager.add_ui_from_string(ui_str)

    def deactivate(self, window):
        manager = self._window.get_ui_manager()
        manager.remove_ui(self._ui_id)
        manager.remove_action_group(self._action_group)
        manager.ensure_update()

    def update_ui(self, window):
        pass

    def on_lf_to_br_activate(self, action):
        view = self._window.get_active_view()
        buf = view.get_buffer()
        try:
            begin, end = buf.get_selection_bounds()
        except:
            self.messagebox("変換したいテキストを選択してください")
            return
        text = begin.get_text(end)
        lf = "\n"
        if "\r" in text:
            lf = "\r\n"
        lines = text.split(lf)
        result = []
        for line in lines:
            result.append("%s<br />" % line)
        buf.delete_selection(True, True)
        buf.insert_at_cursor(lf.join(result))

    def messagebox(self, text):
        dlg = gtk.MessageDialog(self._window,
                                gtk.DIALOG_MODAL,
                                gtk.MESSAGE_WARNING,
                                gtk.BUTTONS_OK,
                                text)
        r = dlg.run()
        dlg.destroy()
